@@ -45,7 +45,13 @@ sub AUTOLOAD {
 sub nick {$_[0]->name};
 sub displayname {
     my $self = shift;
-    return defined $self->card?$self->card:$self->name;
+    my $f = $self->client->search_friend(id=>$self->id);
+    if(defined $f){
+        return $f->markname // $self->card // $self->name;
+    }
+    else{
+        return defined $self->card?$self->card:$self->name;
+    }
 }
 
 sub update{
